@@ -7,10 +7,10 @@ def show(canvas, title="Toyplot Figure"):
 
   Parameters
   ----------
-  canvas : :class:`toyplot.Canvas`
+  canvas: :class:`toyplot.Canvas`
     The canvas to be displayed.
 
-  title : string, optional
+  title: string, optional
     Optional page title to be displayed in the browser.
 
   Notes
@@ -32,6 +32,6 @@ def show(canvas, title="Toyplot Figure"):
   body.append(figure)
 
   fd, path = tempfile.mkstemp(suffix=".html")
-  with os.fdopen(fd, "w") as file:
+  with os.fdopen(fd, "wb") as file:
     file.write(xml.tostring(html, method="html"))
   webbrowser.open("file://" + path, new=1, autoraise=True)
