@@ -9,15 +9,15 @@ def show(canvas, title="Toyplot Figure"):
 
   Parameters
   ----------
-  canvas : :class:`toyplot.Canvas`
+  canvas: :class:`toyplot.Canvas`
     The canvas to be displayed.
 
-  title : string, optional
+  title: string, optional
     Optional page title to be displayed in the browser.
 
   Returns
   -------
-  browser : selenium webdriver object that can be used to control the browser.
+  browser: selenium webdriver object that can be used to control the browser.
 
   Notes
   -----
@@ -38,7 +38,7 @@ def show(canvas, title="Toyplot Figure"):
   body.append(figure)
 
   fd, path = tempfile.mkstemp(suffix=".html")
-  with os.fdopen(fd, "w") as file:
+  with os.fdopen(fd, "wb") as file:
     file.write(xml.tostring(html, method="html"))
 
   browser = selenium.webdriver.Firefox()
